@@ -28,6 +28,9 @@ from .message import Conform
 from .pagepanel import PagePanel
 from .markdown import Markdown
 from .custom_camera import CustomCamera, QrReader
+from .defaultimage import *
+from .price import *
+
 if kivy.platform in ['win','linux', 'macosx']:
 	from .camerawithmic import ScreenWithMic
 from .camerawithmic import CameraWithMic
